==> ksystemlog_4.13.0.orig.tar.xz: ksystemlog-4.13.0/src/modes/authentication/authenticationFactory.cpp <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include "authenticationFactory.h"

#include <QList>


#include "logMode.h"
#include "logging.h"

#include "simpleAction.h"
#include "authenticationLogMode.h"

#include "logModeFactory.h"

QList<LogMode*> AuthenticationLogModeFactory::createLogModes() const {
	QList<LogMode*> logModes;
	logModes.append(new AuthenticationLogMode());
	return logModes;
}

LogModeAction* AuthenticationLogModeFactory::createLogModeAction() const {
	LogMode* logMode = Globals::instance()->findLogMode(QLatin1String( AUTHENTICATION_LOG_MODE_ID ));
	SimpleAction* logModeAction = new SimpleAction(logMode->action(), logMode);

	return logModeAction;
}

==> ksystemlog-17.03.80.tar.xz: ksystemlog-17.03.80/src/modes/authentication/authenticationFactory.cpp <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include "authenticationFactory.h"

#include <QList>

#include "logMode.h"
#include "logging.h"

#include "simpleAction.h"
#include "authenticationLogMode.h"

#include "logModeFactory.h"

QList<LogMode *> AuthenticationLogModeFactory::createLogModes() const
{
    QList<LogMode *> logModes;
    logModes.append(new AuthenticationLogMode());
    return logModes;
}

LogModeAction *AuthenticationLogModeFactory::createLogModeAction() const
{
    LogMode *logMode = Globals::instance().findLogMode(QStringLiteral(AUTHENTICATION_LOG_MODE_ID));

    if (!logMode->filesExist())
        return nullptr;

    SimpleAction *logModeAction = new SimpleAction(logMode->action(), logMode);

    return logModeAction;
}
